@@ -31,13 +31,11 @@
 #include <libpanel-util/panel-glib.h>
 
 #include "launcher.h"
-#include "menu.h"
 #include "panel.h"
 #include "panel-applets-manager.h"
 #include "panel-applet-frame.h"
 #include "panel-action-button.h"
 #include "panel-toplevel.h"
-#include "panel-menu-button.h"
 #include "panel-layout.h"
 #include "panel-lockdown.h"
 #include "panel-util.h"
@@ -95,8 +93,6 @@ typedef struct {
 	GIcon                 *icon;
 	PanelActionButtonType  action_type;
 	char                  *launcher_path;
-	char                  *menu_filename;
-	char                  *menu_path;
 	char                  *iid;
 } PanelAddtoItemInfo;
 
@@ -126,30 +122,11 @@ panel_addto_applet_info_sort_func (PanelAddtoItemInfo *a,
 	return g_utf8_collate (a->name, b->name);
 }
 
-static GSList *
-prepend_internal_applets (GSList *list)
-{
-	PanelAddtoItemInfo *internal;
-
-	internal = g_new0 (PanelAddtoItemInfo, 1);
-	internal->type = PANEL_ADDTO_MENU;
-	internal->name = g_strdup (_("Main Menu"));
-	internal->description = g_strdup (_("The main GNOME menu"));
-	internal->icon = g_themed_icon_new (PANEL_ICON_MAIN_MENU);
-	internal->action_type = PANEL_ACTION_NONE;
-	internal->iid = g_strdup ("MENU:MAIN");
-	list = g_slist_prepend (list, internal);
-
-	return list;
-}
-
 static GSList *
 panel_addto_prepend_internal_applets (GSList *list)
 {
 	int i;
 
-	list = prepend_internal_applets (list);
-
 	for (i = PANEL_ACTION_LOCK; i < PANEL_ACTION_LAST; i++) {
 		PanelAddtoItemInfo *info;
 
@@ -469,19 +446,9 @@ panel_addto_prepend_directory (GSList             **parent_list,
 	data->item_info.name          = g_strdup (gmenu_tree_directory_get_name (directory));
 	data->item_info.description   = g_strdup (gmenu_tree_directory_get_comment (directory));
 	data->item_info.icon          = icon;
-	data->item_info.menu_filename = g_strdup (filename);
-	data->item_info.menu_path     = gmenu_tree_directory_make_path (directory, NULL);
-
-	/* We should set the iid here to something and do
-	 * iid = g_strdup_printf ("MENU:%s", tfr->name)
-	 * but this means we'd have to free the iid later
-	 * and this would complexify too much the free
-	 * function.
-	 * So the iid is built when we select the row.
-	 */
 
 	*parent_list = g_slist_prepend (*parent_list, data);
-			
+
 	/* We always want to show everything in non-root directories */
 	panel_addto_make_application_list (&data->children, directory,
 					   filename, PANEL_ADDTO_MENU_SHOW_ALL);
@@ -585,15 +552,22 @@ panel_addto_populate_application_model (GtkTreeStore *store,
 	GSList            *app;
 
 	for (app = app_list; app != NULL; app = app->next) {
+		PanelAddtoItemInfo *column_data;
+
 		data = app->data;
 		gtk_tree_store_append (store, &iter, parent);
 
 		text = panel_addto_make_text (data->item_info.name,
 					      data->item_info.description);
+
+		column_data = NULL;
+		if (data->item_info.type != PANEL_ADDTO_MENU)
+			column_data = &data->item_info;
+
 		gtk_tree_store_set (store, &iter,
 				    COLUMN_ICON, data->item_info.icon,
 				    COLUMN_TEXT, text,
-				    COLUMN_DATA, &(data->item_info),
+				    COLUMN_DATA, column_data,
 				    COLUMN_SEARCH, data->item_info.name,
 				    -1);
 
@@ -606,6 +580,14 @@ panel_addto_populate_application_model (GtkTreeStore *store,
 	}
 }
 
+static gchar *
+get_applications_menu (void)
+{
+	const gchar *xdg_menu_prefx = g_getenv ("XDG_MENU_PREFIX");
+	return g_strdup_printf ("%sapplications.menu",
+	                        !PANEL_GLIB_STR_EMPTY (xdg_menu_prefx) ? xdg_menu_prefx : "gnome-");
+}
+
 static void
 panel_addto_make_application_model (PanelAddtoDialog *dialog)
 {
@@ -685,11 +667,70 @@ panel_addto_make_application_model (PanelAddtoDialog *dialog)
 						dialog, NULL);
 }
 
+typedef struct
+{
+	PanelAddtoDialog *dialog;
+	gchar            *iid;
+} InitialSetupData;
+
+static InitialSetupData *
+initial_setup_data_new (PanelAddtoDialog *dialog,
+                        const gchar      *iid)
+{
+	InitialSetupData *data;
+
+	data = g_new0 (InitialSetupData, 1);
+
+	data->dialog = g_object_ref (dialog);
+	data->iid = g_strdup (iid);
+
+	return data;
+}
+
+static void
+initial_setup_data_free (gpointer user_data)
+{
+	InitialSetupData *data;
+
+	data = (InitialSetupData *) user_data;
+
+	g_object_unref (data->dialog);
+	g_free (data->iid);
+	g_free (data);
+}
+
+static void
+initial_setup_dialog_cb (GpInitialSetupDialog *dialog,
+                         gboolean              canceled,
+                         gpointer              user_data)
+{
+	InitialSetupData *data;
+	int pack_index;
+	GVariant *initial_settings;
+
+	data = (InitialSetupData *) user_data;
+
+	if (canceled)
+		return;
+
+	pack_index = panel_widget_get_new_pack_index (data->dialog->panel_widget,
+	                                              data->dialog->insert_pack_type);
+
+	initial_settings = gp_initital_setup_dialog_get_settings (dialog);
+
+	panel_applet_frame_create (data->dialog->panel_widget->toplevel,
+	                           data->dialog->insert_pack_type, pack_index,
+	                           data->iid, initial_settings);
+
+	g_variant_unref (initial_settings);
+}
+
 static void
 panel_addto_add_item (PanelAddtoDialog   *dialog,
 	 	      PanelAddtoItemInfo *item_info)
 {
 	int pack_index;
+	InitialSetupData *data;
 
 	g_assert (item_info != NULL);
 
@@ -698,10 +739,16 @@ panel_addto_add_item (PanelAddtoDialog   *dialog,
 
 	switch (item_info->type) {
 	case PANEL_ADDTO_APPLET:
-		panel_applet_frame_create (dialog->panel_widget->toplevel,
-					   dialog->insert_pack_type,
-					   pack_index,
-					   item_info->iid);
+		data = initial_setup_data_new (dialog, item_info->iid);
+
+		if (!panel_applets_manager_open_initial_setup_dialog (item_info->iid,
+		                                                      GTK_WINDOW (dialog),
+		                                                      initial_setup_dialog_cb,
+		                                                      data, initial_setup_data_free)) {
+			panel_applet_frame_create (dialog->panel_widget->toplevel,
+			                           dialog->insert_pack_type, pack_index,
+			                           item_info->iid, NULL);
+		}
 		break;
 	case PANEL_ADDTO_ACTION:
 		panel_action_button_create (dialog->panel_widget->toplevel,
@@ -723,13 +770,6 @@ panel_addto_add_item (PanelAddtoDialog   *dialog,
 				    dialog->insert_pack_type);
 		break;
 	case PANEL_ADDTO_MENU:
-		panel_menu_button_create (dialog->panel_widget->toplevel,
-					  dialog->insert_pack_type,
-					  pack_index,
-					  item_info->menu_filename,
-					  item_info->menu_path,
-					  item_info->name);
-		break;
 	default:
 		break;
 	}
@@ -838,12 +878,6 @@ panel_addto_dialog_free_item_info (PanelAddtoItemInfo *item_info)
 
 	g_free (item_info->launcher_path);
 	item_info->launcher_path = NULL;
-
-	g_free (item_info->menu_filename);
-	item_info->menu_filename = NULL;
-
-	g_free (item_info->menu_path);
-	item_info->menu_path = NULL;
 }
 
 static void
@@ -977,7 +1011,6 @@ panel_addto_selection_changed (PanelAddtoDialog *dialog,
 	GtkTreeIter         iter;
 	GtkTreeIter         filter_iter;
 	PanelAddtoItemInfo *data;
-	char               *iid;
 
 	if (!gtk_tree_selection_get_selected (selection,
 					      &filter_model,
@@ -993,6 +1026,7 @@ panel_addto_selection_changed (PanelAddtoDialog *dialog,
 	gtk_tree_model_get (child_model, &iter, COLUMN_DATA, &data, -1);
 
 	if (!data) {
+		gtk_tree_view_unset_rows_drag_source (GTK_TREE_VIEW (dialog->tree_view));
 		gtk_widget_set_sensitive (GTK_WIDGET (dialog->add_button),
 					  FALSE);
 		return;
@@ -1019,17 +1053,6 @@ panel_addto_selection_changed (PanelAddtoDialog *dialog,
 		} else if (data->type == PANEL_ADDTO_LAUNCHER_MENU) {
 			gtk_tree_view_unset_rows_drag_source (GTK_TREE_VIEW (dialog->tree_view));
 		} else if (data->type == PANEL_ADDTO_MENU) {
-			/* build the iid for menus other than the main menu */
-			if (data->iid == NULL) {
-				iid = g_strdup_printf ("MENU:%s/%s",
-						       data->menu_filename,
-						       data->menu_path);
-			} else {
-				iid = g_strdup (data->iid);
-			}
-			panel_addto_setup_internal_applet_drag (GTK_TREE_VIEW (dialog->tree_view),
-							        iid);
-			g_free (iid);
 		} else {
 			panel_addto_setup_internal_applet_drag (GTK_TREE_VIEW (dialog->tree_view),
 							        data->iid);
