@@ -36,7 +36,6 @@
 #include "panel-ditem-editor.h"
 #include "panel-icon-names.h"
 #include "panel-util.h"
-#include "panel-marshal.h"
 
 struct _PanelDItemEditorPrivate
 {
@@ -164,9 +163,7 @@ enum {
 
 static guint ditem_edit_signals[LAST_SIGNAL] = { 0 };
 
-#define PANEL_DITEM_EDITOR_GET_PRIVATE(o)  (PANEL_DITEM_EDITOR (o)->priv)
-
-G_DEFINE_TYPE (PanelDItemEditor, panel_ditem_editor, GTK_TYPE_DIALOG)
+G_DEFINE_TYPE_WITH_PRIVATE (PanelDItemEditor, panel_ditem_editor, GTK_TYPE_DIALOG)
 
 static void panel_ditem_editor_setup_ui (PanelDItemEditor *dialog);
 
@@ -376,9 +373,6 @@ panel_ditem_editor_class_init (PanelDItemEditorClass *class)
         gobject_class->set_property = panel_ditem_editor_set_property;
         gobject_class->dispose = panel_ditem_editor_dispose;
 
-	g_type_class_add_private (class,
-				  sizeof (PanelDItemEditorPrivate));
-
 	ditem_edit_signals[SAVED] =
 		g_signal_new ("saved",
 			      G_TYPE_FROM_CLASS (gobject_class),
@@ -387,7 +381,7 @@ panel_ditem_editor_class_init (PanelDItemEditorClass *class)
 					       changed),
 			      NULL,
 			      NULL,
-			      g_cclosure_marshal_VOID__VOID,
+			      NULL,
 			      G_TYPE_NONE, 0);
 
 	ditem_edit_signals[CHANGED] =
@@ -398,7 +392,7 @@ panel_ditem_editor_class_init (PanelDItemEditorClass *class)
 					       changed),
 			      NULL,
 			      NULL,
-			      g_cclosure_marshal_VOID__VOID,
+			      NULL,
 			      G_TYPE_NONE, 0);
 
 	ditem_edit_signals[NAME_CHANGED] =
@@ -409,7 +403,7 @@ panel_ditem_editor_class_init (PanelDItemEditorClass *class)
 					       name_changed),
 			      NULL,
 			      NULL,
-			      g_cclosure_marshal_VOID__STRING,
+			      NULL,
 			      G_TYPE_NONE, 1,
 			      G_TYPE_STRING);
 
@@ -421,7 +415,7 @@ panel_ditem_editor_class_init (PanelDItemEditorClass *class)
 					       command_changed),
 			      NULL,
 			      NULL,
-			      g_cclosure_marshal_VOID__STRING,
+			      NULL,
 			      G_TYPE_NONE, 1,
 			      G_TYPE_STRING);
 
@@ -433,7 +427,7 @@ panel_ditem_editor_class_init (PanelDItemEditorClass *class)
 					       comment_changed),
 			      NULL,
 			      NULL,
-			      g_cclosure_marshal_VOID__STRING,
+			      NULL,
 			      G_TYPE_NONE, 1,
 			      G_TYPE_STRING);
 
@@ -445,7 +439,7 @@ panel_ditem_editor_class_init (PanelDItemEditorClass *class)
 					       icon_changed),
 			      NULL,
 			      NULL,
-			      g_cclosure_marshal_VOID__STRING,
+			      NULL,
 			      G_TYPE_NONE, 1,
 			      G_TYPE_STRING);
 
@@ -457,7 +451,7 @@ panel_ditem_editor_class_init (PanelDItemEditorClass *class)
 					       error_reported),
 			      NULL,
 			      NULL,
-			      panel_marshal_VOID__STRING_STRING,
+			      NULL,
 			      G_TYPE_NONE, 2,
 			      G_TYPE_STRING, G_TYPE_STRING);
 
@@ -1101,9 +1095,7 @@ panel_ditem_editor_init (PanelDItemEditor *dialog)
 {
 	PanelDItemEditorPrivate *priv;
 
-	priv = G_TYPE_INSTANCE_GET_PRIVATE (dialog,
-					    PANEL_TYPE_DITEM_EDITOR,
-					    PanelDItemEditorPrivate);
+	priv = panel_ditem_editor_get_instance_private (dialog);
 
 	dialog->priv = priv;
 
