@@ -80,12 +80,12 @@ static const gchar *files_to_check[CHECK_NB] = {
 
 static GObject *systz_singleton = NULL;
 
-G_DEFINE_TYPE (SystemTimezone, system_timezone, G_TYPE_OBJECT)
-
-typedef struct {
+struct _SystemTimezonePrivate {
         char *tz;
         GFileMonitor *monitors[CHECK_NB];
-} SystemTimezonePrivate;
+};
+
+G_DEFINE_TYPE_WITH_PRIVATE (SystemTimezone, system_timezone, G_TYPE_OBJECT)
 
 static GObject *system_timezone_constructor (GType                  type,
                                              guint                  n_construct_properties,
@@ -99,8 +99,6 @@ static void system_timezone_monitor_changed (GFileMonitor *handle,
                                              gpointer user_data);
 static char *system_timezone_find (void);
 
-#define PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), SYSTEM_TIMEZONE_TYPE, SystemTimezonePrivate))
-
 SystemTimezone *
 system_timezone_new (void)
 {
@@ -110,12 +108,9 @@ system_timezone_new (void)
 const char *
 system_timezone_get (SystemTimezone *systz)
 {
-        SystemTimezonePrivate *priv;
-
         g_return_val_if_fail (IS_SYSTEM_TIMEZONE (systz), NULL);
 
-        priv = PRIVATE (systz);
-        return priv->tz;
+        return systz->priv->tz;
 }
 
 static void
@@ -125,19 +120,18 @@ system_timezone_class_init (SystemTimezoneClass *class)
 
         g_obj_class->constructor = system_timezone_constructor;
         g_obj_class->finalize = system_timezone_finalize;
-
-        g_type_class_add_private (class, sizeof (SystemTimezonePrivate));
 }
 
 static void
 system_timezone_init (SystemTimezone *systz)
 {
         int i;
-        SystemTimezonePrivate *priv = PRIVATE (systz);
 
-        priv->tz = NULL;
+        systz->priv = system_timezone_get_instance_private (systz);
+
+        systz->priv->tz = NULL;
         for (i = 0; i < CHECK_NB; i++) 
-                priv->monitors[i] = NULL;
+                systz->priv->monitors[i] = NULL;
 }
 
 static GObject *
@@ -146,6 +140,7 @@ system_timezone_constructor (GType                  type,
                              GObjectConstructParam *construct_properties)
 {
         GObject *obj;
+        SystemTimezone *systz;
         SystemTimezonePrivate *priv;
         int i;
 
@@ -158,7 +153,8 @@ system_timezone_constructor (GType                  type,
                                                 n_construct_properties,
                                                 construct_properties);
 
-        priv = PRIVATE (obj);
+        systz = SYSTEM_TIMEZONE (obj);
+        priv = systz->priv;
 
         priv->tz = system_timezone_find ();
 
@@ -202,7 +198,11 @@ static void
 system_timezone_finalize (GObject *obj)
 {
         int i;
-        SystemTimezonePrivate *priv = PRIVATE (obj);
+        SystemTimezone *systz;
+        SystemTimezonePrivate *priv;
+
+        systz = SYSTEM_TIMEZONE (obj);
+        priv = systz->priv;
 
         if (priv->tz) {
                 g_free (priv->tz);
@@ -229,9 +229,13 @@ system_timezone_monitor_changed (GFileMonitor *handle,
                                  GFileMonitorEvent event,
                                  gpointer user_data)
 {
-        SystemTimezonePrivate *priv = PRIVATE (user_data);
+        SystemTimezone *systz;
+        SystemTimezonePrivate *priv;
         char *new_tz;
 
+        systz = SYSTEM_TIMEZONE (user_data);
+        priv = systz->priv;
+
         if (event != G_FILE_MONITOR_EVENT_CHANGED &&
             event != G_FILE_MONITOR_EVENT_CHANGES_DONE_HINT &&
             event != G_FILE_MONITOR_EVENT_DELETED &&
@@ -249,7 +253,6 @@ system_timezone_monitor_changed (GFileMonitor *handle,
                 g_free (new_tz);
 }
 
-
 /*
  * Code to deal with the system timezone on all distros.
  * There's no dependency on the SystemTimezone GObject here.
